@@ -1,7 +1,7 @@
 """
 Type annotations for comprehendmedical service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehendmedical/type_defs/)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Union
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AttributeNameType,
     EntitySubTypeType,
@@ -127,54 +125,58 @@ __all__ = (
 AttributeTypeDef = TypedDict(
     "AttributeTypeDef",
     {
-        "Type": NotRequired[EntitySubTypeType],
-        "Score": NotRequired[float],
-        "RelationshipScore": NotRequired[float],
-        "RelationshipType": NotRequired[RelationshipTypeType],
-        "Id": NotRequired[int],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Text": NotRequired[str],
-        "Category": NotRequired[EntityTypeType],
-        "Traits": NotRequired[List["TraitTypeDef"]],
+        "Type": EntitySubTypeType,
+        "Score": float,
+        "RelationshipScore": float,
+        "RelationshipType": RelationshipTypeType,
+        "Id": int,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Text": str,
+        "Category": EntityTypeType,
+        "Traits": List["TraitTypeDef"],
     },
+    total=False,
 )
 
 CharactersTypeDef = TypedDict(
     "CharactersTypeDef",
     {
-        "OriginalTextCharacters": NotRequired[int],
+        "OriginalTextCharacters": int,
     },
+    total=False,
 )
 
 ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
     "ComprehendMedicalAsyncJobFilterTypeDef",
     {
-        "JobName": NotRequired[str],
-        "JobStatus": NotRequired[JobStatusType],
-        "SubmitTimeBefore": NotRequired[Union[datetime, str]],
-        "SubmitTimeAfter": NotRequired[Union[datetime, str]],
+        "JobName": str,
+        "JobStatus": JobStatusType,
+        "SubmitTimeBefore": Union[datetime, str],
+        "SubmitTimeAfter": Union[datetime, str],
     },
+    total=False,
 )
 
 ComprehendMedicalAsyncJobPropertiesTypeDef = TypedDict(
     "ComprehendMedicalAsyncJobPropertiesTypeDef",
     {
-        "JobId": NotRequired[str],
-        "JobName": NotRequired[str],
-        "JobStatus": NotRequired[JobStatusType],
-        "Message": NotRequired[str],
-        "SubmitTime": NotRequired[datetime],
-        "EndTime": NotRequired[datetime],
-        "ExpirationTime": NotRequired[datetime],
-        "InputDataConfig": NotRequired["InputDataConfigTypeDef"],
-        "OutputDataConfig": NotRequired["OutputDataConfigTypeDef"],
-        "LanguageCode": NotRequired[Literal["en"]],
-        "DataAccessRoleArn": NotRequired[str],
-        "ManifestFilePath": NotRequired[str],
-        "KMSKey": NotRequired[str],
-        "ModelVersion": NotRequired[str],
+        "JobId": str,
+        "JobName": str,
+        "JobStatus": JobStatusType,
+        "Message": str,
+        "SubmitTime": datetime,
+        "EndTime": datetime,
+        "ExpirationTime": datetime,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "LanguageCode": Literal["en"],
+        "DataAccessRoleArn": str,
+        "ManifestFilePath": str,
+        "KMSKey": str,
+        "ModelVersion": str,
     },
+    total=False,
 )
 
 DescribeEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
@@ -308,65 +310,70 @@ DetectPHIResponseTypeDef = TypedDict(
 EntityTypeDef = TypedDict(
     "EntityTypeDef",
     {
-        "Id": NotRequired[int],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Score": NotRequired[float],
-        "Text": NotRequired[str],
-        "Category": NotRequired[EntityTypeType],
-        "Type": NotRequired[EntitySubTypeType],
-        "Traits": NotRequired[List["TraitTypeDef"]],
-        "Attributes": NotRequired[List["AttributeTypeDef"]],
+        "Id": int,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Score": float,
+        "Text": str,
+        "Category": EntityTypeType,
+        "Type": EntitySubTypeType,
+        "Traits": List["TraitTypeDef"],
+        "Attributes": List["AttributeTypeDef"],
     },
+    total=False,
 )
 
 ICD10CMAttributeTypeDef = TypedDict(
     "ICD10CMAttributeTypeDef",
     {
-        "Type": NotRequired[ICD10CMAttributeTypeType],
-        "Score": NotRequired[float],
-        "RelationshipScore": NotRequired[float],
-        "Id": NotRequired[int],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Text": NotRequired[str],
-        "Traits": NotRequired[List["ICD10CMTraitTypeDef"]],
-        "Category": NotRequired[ICD10CMEntityTypeType],
-        "RelationshipType": NotRequired[ICD10CMRelationshipTypeType],
+        "Type": ICD10CMAttributeTypeType,
+        "Score": float,
+        "RelationshipScore": float,
+        "Id": int,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Text": str,
+        "Traits": List["ICD10CMTraitTypeDef"],
+        "Category": ICD10CMEntityTypeType,
+        "RelationshipType": ICD10CMRelationshipTypeType,
     },
+    total=False,
 )
 
 ICD10CMConceptTypeDef = TypedDict(
     "ICD10CMConceptTypeDef",
     {
-        "Description": NotRequired[str],
-        "Code": NotRequired[str],
-        "Score": NotRequired[float],
+        "Description": str,
+        "Code": str,
+        "Score": float,
     },
+    total=False,
 )
 
 ICD10CMEntityTypeDef = TypedDict(
     "ICD10CMEntityTypeDef",
     {
-        "Id": NotRequired[int],
-        "Text": NotRequired[str],
-        "Category": NotRequired[Literal["MEDICAL_CONDITION"]],
-        "Type": NotRequired[ICD10CMEntityTypeType],
-        "Score": NotRequired[float],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Attributes": NotRequired[List["ICD10CMAttributeTypeDef"]],
-        "Traits": NotRequired[List["ICD10CMTraitTypeDef"]],
-        "ICD10CMConcepts": NotRequired[List["ICD10CMConceptTypeDef"]],
+        "Id": int,
+        "Text": str,
+        "Category": Literal["MEDICAL_CONDITION"],
+        "Type": ICD10CMEntityTypeType,
+        "Score": float,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Attributes": List["ICD10CMAttributeTypeDef"],
+        "Traits": List["ICD10CMTraitTypeDef"],
+        "ICD10CMConcepts": List["ICD10CMConceptTypeDef"],
     },
+    total=False,
 )
 
 ICD10CMTraitTypeDef = TypedDict(
     "ICD10CMTraitTypeDef",
     {
-        "Name": NotRequired[ICD10CMTraitNameType],
-        "Score": NotRequired[float],
+        "Name": ICD10CMTraitNameType,
+        "Score": float,
     },
+    total=False,
 )
 
 InferICD10CMRequestRequestTypeDef = TypedDict(
@@ -422,21 +429,33 @@ InferSNOMEDCTResponseTypeDef = TypedDict(
     },
 )
 
-InputDataConfigTypeDef = TypedDict(
-    "InputDataConfigTypeDef",
+_RequiredInputDataConfigTypeDef = TypedDict(
+    "_RequiredInputDataConfigTypeDef",
     {
         "S3Bucket": str,
-        "S3Key": NotRequired[str],
     },
 )
+_OptionalInputDataConfigTypeDef = TypedDict(
+    "_OptionalInputDataConfigTypeDef",
+    {
+        "S3Key": str,
+    },
+    total=False,
+)
+
+
+class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputDataConfigTypeDef):
+    pass
+
 
 ListEntitiesDetectionV2JobsRequestRequestTypeDef = TypedDict(
     "ListEntitiesDetectionV2JobsRequestRequestTypeDef",
     {
-        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
@@ -453,10 +472,11 @@ ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
 ListICD10CMInferenceJobsRequestRequestTypeDef = TypedDict(
     "ListICD10CMInferenceJobsRequestRequestTypeDef",
     {
-        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
@@ -473,10 +493,11 @@ ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
 ListPHIDetectionJobsRequestRequestTypeDef = TypedDict(
     "ListPHIDetectionJobsRequestRequestTypeDef",
     {
-        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListPHIDetectionJobsResponseTypeDef = TypedDict(
@@ -493,10 +514,11 @@ ListPHIDetectionJobsResponseTypeDef = TypedDict(
 ListRxNormInferenceJobsRequestRequestTypeDef = TypedDict(
     "ListRxNormInferenceJobsRequestRequestTypeDef",
     {
-        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListRxNormInferenceJobsResponseTypeDef = TypedDict(
@@ -513,10 +535,11 @@ ListRxNormInferenceJobsResponseTypeDef = TypedDict(
 ListSNOMEDCTInferenceJobsRequestRequestTypeDef = TypedDict(
     "ListSNOMEDCTInferenceJobsRequestRequestTypeDef",
     {
-        "Filter": NotRequired["ComprehendMedicalAsyncJobFilterTypeDef"],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListSNOMEDCTInferenceJobsResponseTypeDef = TypedDict(
@@ -530,13 +553,24 @@ ListSNOMEDCTInferenceJobsResponseTypeDef = TypedDict(
     },
 )
 
-OutputDataConfigTypeDef = TypedDict(
-    "OutputDataConfigTypeDef",
+_RequiredOutputDataConfigTypeDef = TypedDict(
+    "_RequiredOutputDataConfigTypeDef",
     {
         "S3Bucket": str,
-        "S3Key": NotRequired[str],
     },
 )
+_OptionalOutputDataConfigTypeDef = TypedDict(
+    "_OptionalOutputDataConfigTypeDef",
+    {
+        "S3Key": str,
+    },
+    total=False,
+)
+
+
+class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputDataConfigTypeDef):
+    pass
+
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -552,121 +586,144 @@ ResponseMetadataTypeDef = TypedDict(
 RxNormAttributeTypeDef = TypedDict(
     "RxNormAttributeTypeDef",
     {
-        "Type": NotRequired[RxNormAttributeTypeType],
-        "Score": NotRequired[float],
-        "RelationshipScore": NotRequired[float],
-        "Id": NotRequired[int],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Text": NotRequired[str],
-        "Traits": NotRequired[List["RxNormTraitTypeDef"]],
+        "Type": RxNormAttributeTypeType,
+        "Score": float,
+        "RelationshipScore": float,
+        "Id": int,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Text": str,
+        "Traits": List["RxNormTraitTypeDef"],
     },
+    total=False,
 )
 
 RxNormConceptTypeDef = TypedDict(
     "RxNormConceptTypeDef",
     {
-        "Description": NotRequired[str],
-        "Code": NotRequired[str],
-        "Score": NotRequired[float],
+        "Description": str,
+        "Code": str,
+        "Score": float,
     },
+    total=False,
 )
 
 RxNormEntityTypeDef = TypedDict(
     "RxNormEntityTypeDef",
     {
-        "Id": NotRequired[int],
-        "Text": NotRequired[str],
-        "Category": NotRequired[Literal["MEDICATION"]],
-        "Type": NotRequired[RxNormEntityTypeType],
-        "Score": NotRequired[float],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Attributes": NotRequired[List["RxNormAttributeTypeDef"]],
-        "Traits": NotRequired[List["RxNormTraitTypeDef"]],
-        "RxNormConcepts": NotRequired[List["RxNormConceptTypeDef"]],
+        "Id": int,
+        "Text": str,
+        "Category": Literal["MEDICATION"],
+        "Type": RxNormEntityTypeType,
+        "Score": float,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Attributes": List["RxNormAttributeTypeDef"],
+        "Traits": List["RxNormTraitTypeDef"],
+        "RxNormConcepts": List["RxNormConceptTypeDef"],
     },
+    total=False,
 )
 
 RxNormTraitTypeDef = TypedDict(
     "RxNormTraitTypeDef",
     {
-        "Name": NotRequired[Literal["NEGATION"]],
-        "Score": NotRequired[float],
+        "Name": Literal["NEGATION"],
+        "Score": float,
     },
+    total=False,
 )
 
 SNOMEDCTAttributeTypeDef = TypedDict(
     "SNOMEDCTAttributeTypeDef",
     {
-        "Category": NotRequired[SNOMEDCTEntityCategoryType],
-        "Type": NotRequired[SNOMEDCTAttributeTypeType],
-        "Score": NotRequired[float],
-        "RelationshipScore": NotRequired[float],
-        "RelationshipType": NotRequired[SNOMEDCTRelationshipTypeType],
-        "Id": NotRequired[int],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Text": NotRequired[str],
-        "Traits": NotRequired[List["SNOMEDCTTraitTypeDef"]],
-        "SNOMEDCTConcepts": NotRequired[List["SNOMEDCTConceptTypeDef"]],
+        "Category": SNOMEDCTEntityCategoryType,
+        "Type": SNOMEDCTAttributeTypeType,
+        "Score": float,
+        "RelationshipScore": float,
+        "RelationshipType": SNOMEDCTRelationshipTypeType,
+        "Id": int,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Text": str,
+        "Traits": List["SNOMEDCTTraitTypeDef"],
+        "SNOMEDCTConcepts": List["SNOMEDCTConceptTypeDef"],
     },
+    total=False,
 )
 
 SNOMEDCTConceptTypeDef = TypedDict(
     "SNOMEDCTConceptTypeDef",
     {
-        "Description": NotRequired[str],
-        "Code": NotRequired[str],
-        "Score": NotRequired[float],
+        "Description": str,
+        "Code": str,
+        "Score": float,
     },
+    total=False,
 )
 
 SNOMEDCTDetailsTypeDef = TypedDict(
     "SNOMEDCTDetailsTypeDef",
     {
-        "Edition": NotRequired[str],
-        "Language": NotRequired[str],
-        "VersionDate": NotRequired[str],
+        "Edition": str,
+        "Language": str,
+        "VersionDate": str,
     },
+    total=False,
 )
 
 SNOMEDCTEntityTypeDef = TypedDict(
     "SNOMEDCTEntityTypeDef",
     {
-        "Id": NotRequired[int],
-        "Text": NotRequired[str],
-        "Category": NotRequired[SNOMEDCTEntityCategoryType],
-        "Type": NotRequired[SNOMEDCTEntityTypeType],
-        "Score": NotRequired[float],
-        "BeginOffset": NotRequired[int],
-        "EndOffset": NotRequired[int],
-        "Attributes": NotRequired[List["SNOMEDCTAttributeTypeDef"]],
-        "Traits": NotRequired[List["SNOMEDCTTraitTypeDef"]],
-        "SNOMEDCTConcepts": NotRequired[List["SNOMEDCTConceptTypeDef"]],
+        "Id": int,
+        "Text": str,
+        "Category": SNOMEDCTEntityCategoryType,
+        "Type": SNOMEDCTEntityTypeType,
+        "Score": float,
+        "BeginOffset": int,
+        "EndOffset": int,
+        "Attributes": List["SNOMEDCTAttributeTypeDef"],
+        "Traits": List["SNOMEDCTTraitTypeDef"],
+        "SNOMEDCTConcepts": List["SNOMEDCTConceptTypeDef"],
     },
+    total=False,
 )
 
 SNOMEDCTTraitTypeDef = TypedDict(
     "SNOMEDCTTraitTypeDef",
     {
-        "Name": NotRequired[SNOMEDCTTraitNameType],
-        "Score": NotRequired[float],
+        "Name": SNOMEDCTTraitNameType,
+        "Score": float,
     },
+    total=False,
 )
 
-StartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
-    "StartEntitiesDetectionV2JobRequestRequestTypeDef",
+_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
-        "JobName": NotRequired[str],
-        "ClientRequestToken": NotRequired[str],
-        "KMSKey": NotRequired[str],
     },
 )
+_OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartEntitiesDetectionV2JobRequestRequestTypeDef(
+    _RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef,
+    _OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef,
+):
+    pass
+
 
 StartEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "StartEntitiesDetectionV2JobResponseTypeDef",
@@ -676,18 +733,32 @@ StartEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     },
 )
 
-StartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
-    "StartICD10CMInferenceJobRequestRequestTypeDef",
+_RequiredStartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartICD10CMInferenceJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
-        "JobName": NotRequired[str],
-        "ClientRequestToken": NotRequired[str],
-        "KMSKey": NotRequired[str],
     },
 )
+_OptionalStartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartICD10CMInferenceJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartICD10CMInferenceJobRequestRequestTypeDef(
+    _RequiredStartICD10CMInferenceJobRequestRequestTypeDef,
+    _OptionalStartICD10CMInferenceJobRequestRequestTypeDef,
+):
+    pass
+
 
 StartICD10CMInferenceJobResponseTypeDef = TypedDict(
     "StartICD10CMInferenceJobResponseTypeDef",
@@ -697,18 +768,32 @@ StartICD10CMInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
-StartPHIDetectionJobRequestRequestTypeDef = TypedDict(
-    "StartPHIDetectionJobRequestRequestTypeDef",
+_RequiredStartPHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartPHIDetectionJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
-        "JobName": NotRequired[str],
-        "ClientRequestToken": NotRequired[str],
-        "KMSKey": NotRequired[str],
     },
 )
+_OptionalStartPHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartPHIDetectionJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartPHIDetectionJobRequestRequestTypeDef(
+    _RequiredStartPHIDetectionJobRequestRequestTypeDef,
+    _OptionalStartPHIDetectionJobRequestRequestTypeDef,
+):
+    pass
+
 
 StartPHIDetectionJobResponseTypeDef = TypedDict(
     "StartPHIDetectionJobResponseTypeDef",
@@ -718,18 +803,32 @@ StartPHIDetectionJobResponseTypeDef = TypedDict(
     },
 )
 
-StartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
-    "StartRxNormInferenceJobRequestRequestTypeDef",
+_RequiredStartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartRxNormInferenceJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
-        "JobName": NotRequired[str],
-        "ClientRequestToken": NotRequired[str],
-        "KMSKey": NotRequired[str],
     },
 )
+_OptionalStartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartRxNormInferenceJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartRxNormInferenceJobRequestRequestTypeDef(
+    _RequiredStartRxNormInferenceJobRequestRequestTypeDef,
+    _OptionalStartRxNormInferenceJobRequestRequestTypeDef,
+):
+    pass
+
 
 StartRxNormInferenceJobResponseTypeDef = TypedDict(
     "StartRxNormInferenceJobResponseTypeDef",
@@ -739,18 +838,32 @@ StartRxNormInferenceJobResponseTypeDef = TypedDict(
     },
 )
 
-StartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
-    "StartSNOMEDCTInferenceJobRequestRequestTypeDef",
+_RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef",
     {
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": Literal["en"],
-        "JobName": NotRequired[str],
-        "ClientRequestToken": NotRequired[str],
-        "KMSKey": NotRequired[str],
     },
 )
+_OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartSNOMEDCTInferenceJobRequestRequestTypeDef(
+    _RequiredStartSNOMEDCTInferenceJobRequestRequestTypeDef,
+    _OptionalStartSNOMEDCTInferenceJobRequestRequestTypeDef,
+):
+    pass
+
 
 StartSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
     "StartSNOMEDCTInferenceJobResponseTypeDef",
@@ -838,15 +951,17 @@ StopSNOMEDCTInferenceJobResponseTypeDef = TypedDict(
 TraitTypeDef = TypedDict(
     "TraitTypeDef",
     {
-        "Name": NotRequired[AttributeNameType],
-        "Score": NotRequired[float],
+        "Name": AttributeNameType,
+        "Score": float,
     },
+    total=False,
 )
 
 UnmappedAttributeTypeDef = TypedDict(
     "UnmappedAttributeTypeDef",
     {
-        "Type": NotRequired[EntityTypeType],
-        "Attribute": NotRequired["AttributeTypeDef"],
+        "Type": EntityTypeType,
+        "Attribute": "AttributeTypeDef",
     },
+    total=False,
 )
